@@ -9,8 +9,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.6',
- 'BLDLIBRARY': '-lpython3.6m',
+ 'BINLIBDEST': '/usr/lib/python3.7',
+ 'BLDLIBRARY': '-lpython3.7m',
  'BLDSHARED': 'aarch64-linux-gnu-gcc -pthread -shared -Wl,-O1 '
               '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
               ' -Wl,-z,relro',
@@ -36,7 +36,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wno-cast-function-type',
+                            '-Wno-cast-function-type '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-Wdate-time -D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions '
                       ' -Wl,-z,relro',
@@ -53,25 +54,25 @@ build_time_vars = {'ABIFLAGS': 'm',
                 " -Wl,-z,relro' "
                 "'CPPFLAGS=-Wdate-time -D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/lcov-report',
+ 'CONFINCLUDEPY': '/usr/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
              '-D_FORTIFY_SOURCE=2',
  'CXX': 'aarch64-linux-gnu-g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.6 /usr/lib/python3.6/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.6',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.7 /usr/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -87,9 +88,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-36m-aarch64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-37m-aarch64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -132,6 +132,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 1,
+ 'HAVE_CRYPT_R': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -153,6 +154,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -279,6 +281,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
+ 'HAVE_LINUX_VM_SOCKETS_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -287,7 +290,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -313,12 +315,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 1,
+ 'HAVE_PREADV2': 1,
  'HAVE_PRLIMIT': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -326,13 +331,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 1,
+ 'HAVE_PWRITEV2': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -347,7 +353,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -373,6 +378,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 1,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -474,6 +480,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 0,
+ 'HAVE_UUID_ENC_BE': 0,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
+ 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -485,19 +496,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'aarch64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.6m '
-                   '/usr/include/python3.6m',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.7m '
+                   '/usr/include/python3.7m',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.6m',
+ 'INCLUDEPY': '/usr/include/python3.7m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.so.1.0',
+ 'INSTSONAME': 'libpython3.7m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'aarch64-linux-gnu-g++ -pthread -shared -Wl,-O1 '
@@ -505,25 +517,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LDFLAGS': '-Wl,-Bsymbolic-functions  '
             '-Wl,-z,relro',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.so',
+ 'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'aarch64-linux-gnu-gcc -pthread -shared -Wl,-O1 '
              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
              ' -Wl,-z,relro',
- 'LDVERSION': '3.6m',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.6',
+ 'LIBDEST': '/usr/lib/python3.7',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/aarch64-linux-gnu/pkgconfig',
- 'LIBPL': '/usr/lib/python3.6/config-3.6m-aarch64-linux-gnu',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/usr/lib/python3.7/config-3.7m-aarch64-linux-gnu',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
+ 'LIBS': '-lcrypt -lpthread -ldl  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'aarch64-linux-gnu-gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
@@ -535,9 +547,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '-lexpat                     -L/usr/lib -lz  -lexpat',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'linux',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.6',
+ 'MACHDESTLIB': '/usr/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'aarch64-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -545,17 +556,20 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'array  cmath  math  _struct  _random  _elementtree  '
+                   '_pickle  _datetime  _bisect  _heapq  unicodedata  fcntl  '
+                   'spwd  grp  select  _socket  _posixsubprocess  _md5  _sha1  '
+                   '_sha256  _sha512  _sha3  _blake2  syslog  binascii  zlib  '
+                   'pyexpat  posix  errno  pwd  _sre  _codecs  _weakref  '
+                   '_functools  _operator  _collections  _abc  itertools  '
+                   'atexit  _signal  _stat  time  _thread  _locale  _io  '
+                   'zipimport  faulthandler  _tracemalloc  _symtable  '
+                   'xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '-lexpat                     -L/usr/lib -lz  -lexpat',
- 'MODNAMES': '_thread array cmath math _struct _random _elementtree _pickle '
-             '_datetime _bisect _heapq unicodedata fcntl spwd grp select '
-             '_socket _posixsubprocess _md5 _sha1 _sha256 _sha512 _sha3 '
-             '_blake2 syslog binascii zlib pyexpat posix errno pwd _sre '
-             '_codecs _weakref _functools _operator _collections itertools '
-             'atexit _signal _stat time _locale _io zipimport faulthandler '
-             '_tracemalloc _symtable xxsubtype',
- 'MODOBJS': '$(sort   Modules/_threadmodule.o  Modules/arraymodule.o  '
-            'Modules/cmathmodule.o Modules/_math.o  Modules/mathmodule.o '
-            'Modules/_math.o  Modules/_struct.o  Modules/_randommodule.o  '
+ 'MODOBJS': '$(sort   Modules/arraymodule.o  Modules/cmathmodule.o '
+            'Modules/_math.o  Modules/mathmodule.o Modules/_math.o  '
+            'Modules/_struct.o  Modules/_randommodule.o  '
             'Modules/_elementtree.o  Modules/_pickle.o  '
             'Modules/_datetimemodule.o  Modules/_bisectmodule.o  '
             'Modules/_heapqmodule.o  Modules/unicodedata.o  '
@@ -571,8 +585,9 @@ build_time_vars = {'ABIFLAGS': 'm',
             'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
             'Modules/_weakref.o  Modules/_functoolsmodule.o  '
             'Modules/_operator.o  Modules/_collectionsmodule.o  '
-            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
-            'Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
+            'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
@@ -585,6 +600,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '',
+ 'OPENSSL_LDFLAGS': '',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g -fwrapv -O2 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -600,10 +618,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': 'libpython3.so',
@@ -613,18 +631,33 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.6',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
+                             '-fwrapv -O2 -Wall -g '
+                             ' '
+                             ' '
+                             '-fstack-protector-strong -Wformat '
+                             '-Werror=format-security -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wno-cast-function-type '
+                             '-Werror=implicit-function-declaration -IObjects '
+                             '-IInclude -IPython -I. -I../Include -Wdate-time '
+                             '-D_FORTIFY_SOURCE=2 -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
               '-g  '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wno-cast-function-type',
+                     '-Wno-cast-function-type '
+                     '-Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 '
                    '-Wall -g '
                    ' '
@@ -632,13 +665,27 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-fstack-protector-strong -Wformat -Werror=format-security '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wno-cast-function-type '
-                   '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
-                   '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+                   '-Werror=implicit-function-declaration -IObjects -IInclude '
+                   '-IPython -I. -I../Include -Wdate-time -D_FORTIFY_SOURCE=2 '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
                 '-D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-Bsymbolic-functions '
                ' -Wl,-z,relro',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
+                        '-O2 -Wall -g '
+                        ' '
+                        ' '
+                        '-fstack-protector-strong -Wformat -Werror=format-security '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wno-cast-function-type '
+                        '-Werror=implicit-function-declaration -IObjects '
+                        '-IInclude -IPython -I. -I../Include -Wdate-time '
+                        '-D_FORTIFY_SOURCE=2 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -646,12 +693,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
+ 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -664,6 +711,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 8,
@@ -672,7 +720,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m-aarch64-linux-gnu',
+ 'SOABI': 'cpython-37m-aarch64-linux-gnu',
  'SRCDIRS': 'Parser Objects Python Modules Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
@@ -687,24 +735,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.6 ../Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 ../Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
+ 'VERSION': '3.7',
  'VPATH': '..',
- 'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -712,12 +757,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared',
- 'abs_srcdir': '/build/python3.6-FX1Cgd/python3.6-3.6.8/build-shared/..',
+ 'abs_builddir': '/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared',
+ 'abs_srcdir': '/build/python3.7-5gTr8y/python3.7-3.7.3/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
