@@ -694,8 +694,7 @@ class SoftwareProperties(object):
       keyp = "%s/%s.key" % (self.CHANNEL_PATH, channel)
       self.add_key(keyp)
 
-    cdata = (shortcut.add_key, {'keyserver': (self.options and
-                                              self.options.keyserver)})
+    cdata = (shortcut.add_key, {'keyserver': (self.options)})
     def addkey_func():
         func, kwargs = cdata
         msg = "Added key."
@@ -833,7 +832,6 @@ class SoftwareProperties(object):
         return False
     try:
         res = self.apt_key.add(path)
-        self.KeysModified()
         return res
     except:
         return False
@@ -849,7 +847,6 @@ class SoftwareProperties(object):
     """Remove a gnupg key from the list of trusted software vendors"""
     try:
         self.apt_key.rm(keyid)
-        self.KeysModified()
         return True
     except:
         return False
@@ -858,7 +855,6 @@ class SoftwareProperties(object):
     """ Run apt-key update """
     try:
       self.apt_key.update()
-      self.KeysModified()
       return True
     except:
       return False
